# Optical dispersion relations

## Features

* A collection of exact and approximate optical dispersion relations.
* Academic Sources eg textbooks and journal articles.
* Fully tested (see `test/`) so users can calculate with confidence.

## Install

Download the latest release [here](https://github.com/g-duff/optical_dispersion_relations/releases/latest), and install with pip eg:

```sh
pip3 install optical_dispersion_relations-0.0.0-py3-none-any.whl
```

## Contribute

Contributions and conversations warmly welcome.
